tiled.server.object\_cache.ObjectCache
======================================

.. currentmodule:: tiled.server.object_cache

.. autoclass:: ObjectCache

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ObjectCache.__init__
      ~ObjectCache.clear
      ~ObjectCache.discard
      ~ObjectCache.discard_dask
      ~ObjectCache.get
      ~ObjectCache.put
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ObjectCache.available_bytes
      ~ObjectCache.dask_context
   
   